package javax.swing.colorchooser;

import javax.swing.JComponent;
import java.beans.PropertyChangeEvent;
import javax.swing.Icon;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Color;
import java.awt.Component;
import java.awt.Container;
import javax.swing.JLabel;
import javax.swing.JFormattedTextField;
import java.beans.PropertyChangeListener;

final class ColorChooserPanel extends AbstractColorChooserPanel implements PropertyChangeListener
{
    private static final int MASK = -16777216;
    private final ColorModel model;
    private final ColorPanel panel;
    private final DiagramComponent slider;
    private final DiagramComponent diagram;
    private final JFormattedTextField text;
    private final JLabel label;
    
    ColorChooserPanel(ColorModel model) {
        this.model = model;
        this.panel = new ColorPanel(this.model);
        this.slider = new DiagramComponent(this.panel, false);
        this.diagram = new DiagramComponent(this.panel, true);
        this.text = new JFormattedTextField();
        this.label = new JLabel(null, null, 4);
        ValueFormatter.init(6, true, this.text);
    }
    
    @Override
    public void setEnabled(boolean enabled) {
        super.setEnabled(enabled);
        setEnabled(this, enabled);
    }
    
    private static void setEnabled(Container container, boolean enabled) {
        for (Component component : container.getComponents()) {
            component.setEnabled(enabled);
            if ((component instanceof Container)) {
                setEnabled((Container)component, enabled);
            }
        }
    }
    
    @Override
    public void updateChooser() {
        Color colorFromModel = this.getColorFromModel();
        if (colorFromModel != null) {
            this.panel.setColor(colorFromModel);
            this.text.setValue(Integer.valueOf(colorFromModel.getRGB()));
            this.slider.repaint();
            this.diagram.repaint();
        }
    }
    
    @Override
    protected void buildChooser() {
        if (0 == this.getComponentCount()) {
            this.setLayout(new GridBagLayout());
            GridBagConstraints constraints = new GridBagConstraints();
            constraints.gridx = 3;
            constraints.gridwidth = 2;
            constraints.weighty = 1.0;
            constraints.anchor = 11;
            constraints.fill = 2;
            constraints.insets.top = 10;
            constraints.insets.right = 10;
            this.add(this.panel, constraints);
            constraints.gridwidth = 1;
            constraints.weightx = 1.0;
            constraints.weighty = 0.0;
            constraints.anchor = 10;
            constraints.insets.right = 5;
            constraints.insets.bottom = 10;
            this.add(this.label, constraints);
            constraints.gridx = 4;
            constraints.weightx = 0.0;
            constraints.insets.right = 10;
            this.add(this.text, constraints);
            constraints.gridx = 2;
            constraints.gridheight = 2;
            constraints.anchor = 11;
            constraints.ipadx = this.text.getPreferredSize().height;
            constraints.ipady = this.getPreferredSize().height;
            this.add(this.slider, constraints);
            constraints.gridx = 1;
            constraints.insets.left = 10;
            constraints.ipadx = constraints.ipady;
            this.add(this.diagram, constraints);
            this.label.setLabelFor(this.text);
            this.text.addPropertyChangeListener("value", this);
            this.slider.setBorder(this.text.getBorder());
            this.diagram.setBorder(this.text.getBorder());
            setInheritsPopupMenu(this, true);
        }
        String text = this.model.getText(this, "HexCode");
        int n = text != null;
        this.text.setVisible((boolean)n);
        this.text.getAccessibleContext().setAccessibleDescription(text);
        this.label.setVisible((boolean)n);
        if (!(n == 0)) {
            this.label.setText(text);
            int integer = this.model.getInteger(this, "HexCodeMnemonic");
            if (integer > 0) {
                this.label.setDisplayedMnemonic(integer);
                int integer2 = this.model.getInteger(this, "HexCodeMnemonicIndex");
                if (integer2 >= 0) {
                    this.label.setDisplayedMnemonicIndex(integer2);
                }
            }
        }
        this.panel.buildPanel();
    }
    
    @Override
    public String getDisplayName() {
        return this.model.getText(this, "Name");
    }
    
    @Override
    public int getMnemonic() {
        return this.model.getInteger(this, "Mnemonic");
    }
    
    @Override
    public int getDisplayedMnemonicIndex() {
        return this.model.getInteger(this, "DisplayedMnemonicIndex");
    }
    
    @Override
    public Icon getSmallDisplayIcon() {
        return null;
    }
    
    @Override
    public Icon getLargeDisplayIcon() {
        return null;
    }
    
    @Override
    public void propertyChange(PropertyChangeEvent propertyChangeEvent) {
        ColorSelectionModel colorSelectionModel = this.getColorSelectionModel();
        if (colorSelectionModel != null) {
            Object newValue = propertyChangeEvent.getNewValue();
            if ((newValue instanceof Integer)) {
                colorSelectionModel.setSelectedColor(new Color((0xFF000000 & colorSelectionModel.getSelectedColor().getRGB()) | (int)newValue, true));
            }
        }
        this.text.selectAll();
    }
    
    private static void setInheritsPopupMenu(JComponent component, boolean inheritsPopupMenu) {
        component.setInheritsPopupMenu(inheritsPopupMenu);
        for (Component component2 : component.getComponents()) {
            if ((component2 instanceof JComponent)) {
                setInheritsPopupMenu((JComponent)component2, inheritsPopupMenu);
            }
        }
    }
}
